@@ -69,7 +69,7 @@ build_recipe <- function(target, recipe_command,
     cache_path <- cache_value_macro
   }
   if (is_file(target)){
-    target <- paste0("drake::as_drake_filename(\"",
+    target <- paste0("drake::file_store(\"",
       drake::drake_unquote(target), "\")")
   } else{
     target <- drake::drake_quotes(
@@ -84,12 +84,12 @@ build_recipe <- function(target, recipe_command,
   gsub(r_recipe_wildcard(), r_recipe, recipe_command)
 }
 
-#' @title Build a target inside a \code{Makefile}
-#' during \code{make(..., parallelism = "Makefile")}.
+#' @title Build a target inside a `Makefile`
+#'   during `make(..., parallelism = "Makefile")`.
 #' @description Users should not need to call this function directly.
 #' @export
 #' @keywords internal
-#' @return \code{NULL}
+#' @return `NULL`
 #' @param target name of target to make
 #' @param cache_path path to the drake cache
 #' @examples
@@ -133,33 +133,33 @@ mk <- function(
 }
 
 #' @title Return the default value of the
-#' \code{args} argument to \code{\link{make}()}.
-#' @description For \code{make(..., parallelism = "Makefile")},
+#'   `args` argument to [make()].
+#' @description For `make(..., parallelism = "Makefile")`,
 #' this function configures the default
-#' arguments to \code{\link{system2}()}.
+#' arguments to [system2()].
 #' It is an internal function, and most users do not need to
 #' worry about it.
 #' @export
-#' @return \code{args} for \code{\link{system2}(command, args)}
+#' @return `args` for \code{\link{system2}(command, args)}
+#' @inheritParams drake_config
 #' @param jobs number of jobs
-#' @param verbose logical, whether to be verbose
 #' @examples
 #' default_Makefile_args(jobs = 2, verbose = FALSE)
 #' default_Makefile_args(jobs = 4, verbose = TRUE)
 default_Makefile_args <- function(jobs, verbose){
-  out <- paste0("--jobs=", jobs)
+  out <- paste0("--jobs=", jobs_targets(jobs))
   if (!verbose){
     out <- c(out, "--silent")
   }
   return(out)
 }
 
-#' @title Give the default \code{command}
-#' argument to \code{\link{make}()}.
+#' @title Give the default `command`
+#'   argument to [make()].
 #' @description Relevant for
-#' \code{"Makefile"} parallelism only.
+#' `"Makefile"` parallelism only.
 #' @return A character scalar naming a Linux/Unix command
-#' to run a Makefile.
+#'   to run a Makefile.
 #' @export
 #' @examples
 #' default_Makefile_command()
