@@ -1,40 +1,36 @@
 #' @title Generate a flat text log file
-#' to represent the state of the cache.
+#'   to represent the state of the cache.
 #' @description
 #' This functionality is like
 #' \code{\link{make}(..., cache_log_file = TRUE)},
 #' but separated and more customizable.
-#' The \code{drake_cache_log_file} function writes a flat text file
+#' The `drake_cache_log_file()` function writes a flat text file
 #' to represents the state of all the targets and imports in the cache.
-#' If you call it after each \code{\link{make}()}
+#' If you call it after each [make()]
 #' and put the log file under version control,
 #' you can track the changes to your results over time.
 #' This way, your data is versioned alongside your code
 #' in a easy-to-view format. Hopefully, this functionality
 #' is a step toward better data versioning tools.
-#' @seealso \code{\link{drake_cache_log}},
-#' \code{\link{make}},
-#' \code{\link{get_cache}},
-#' \code{\link{default_long_hash_algo}},
-#' \code{\link{short_hash}},
-#' \code{\link{long_hash}}
+#' @seealso [drake_cache_log()],
+#'   [make()],
+#'   [get_cache()],
+#'   [default_long_hash_algo()],
+#'   [short_hash()],
+#'   [long_hash()]
 #' @export
 #' @return There is no return value, but a log file is generated.
 #' @param file character scalar, name of the flat text log file.
-#' @param cache drake cache. See \code{\link{new_cache}()}.
-#' If supplied, \code{path} and \code{search} are ignored.
-#' @param path Root directory of the drake project,
-#' or if \code{search} is \code{TRUE}, either the
-#' project root or a subdirectory of the project.
-#' @param search logical. If \code{TRUE}, search parent directories
-#' to find the nearest drake cache. Otherwise, look in the
-#' current working directory only.
-#' @param verbose whether to print console messages
+#'
+#' @inheritParams cached
+#'
 #' @param jobs number of jobs/workers for parallel processing
+#'
 #' @param targets_only logical, whether to output information
-#' only on the targets in your workflow plan data frame.
-#' If \code{targets_only} is \code{FALSE}, the output will
-#' include the hashes of both targets and imports. 
+#'   only on the targets in your workflow plan data frame.
+#'   If `targets_only` is `FALSE`, the output will
+#'   include the hashes of both targets and imports.
+#'
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -58,7 +54,7 @@ drake_cache_log_file <- function(
   path = getwd(),
   search = TRUE,
   cache = drake::get_cache(path = path, search = search, verbose = verbose),
-  verbose = TRUE,
+  verbose = drake::default_verbose(),
   jobs = 1,
   targets_only = FALSE
 ){
@@ -90,14 +86,14 @@ drake_cache_log_file <- function(
 #' @details A hash is a fingerprint of an object's value.
 #' Together, the hash keys of all your targets and imports
 #' represent the state of your project.
-#' Use \code{drake_cache_log()} to generate a data frame
+#' Use `drake_cache_log()` to generate a data frame
 #' with the hash keys of all the targets and imports
 #' stored in your cache.
 #' This function is particularly useful if you are
 #' storing your drake project in a version control repository.
 #' The cache has a lot of tiny files, so you should not put it
 #' under version control. Instead, save the output
-#' of \code{drake_cache_log()} as a text file after each \code{\link{make}()},
+#' of `drake_cache_log()` as a text file after each [make()],
 #' and put the text file under version control.
 #' That way, you have a changelog of your project's results.
 #' See the examples below for details.
@@ -105,31 +101,27 @@ drake_cache_log_file <- function(
 #' history, the targets may be different than the ones
 #' in your workflow plan data frame.
 #' Also, the keys depend on the short hash algorithm
-#' of your cache (default: \code{\link{default_short_hash_algo}()}).
-#' @seealso \code{\link{drake_cache_log_file}}
-#' \code{\link{cached}},
-#' \code{\link{get_cache}},
-#' \code{\link{default_short_hash_algo}},
-#' \code{\link{default_long_hash_algo}},
-#' \code{\link{short_hash}},
-#' \code{\link{long_hash}}
+#' of your cache (default: [default_short_hash_algo()]).
+#' @seealso [drake_cache_log_file()]
+#'   [cached()],
+#'   [get_cache()],
+#'   [default_short_hash_algo()],
+#'   [default_long_hash_algo()],
+#'   [short_hash()],
+#'   [long_hash()]
 #' @export
 #' @return Data frame of the hash keys of the targets and imports
-#' in the cache
-#' @param cache drake cache. See \code{\link{new_cache}()}.
-#' If supplied, \code{path} and \code{search} are ignored.
-#' @param path Root directory of the drake project,
-#' or if \code{search} is \code{TRUE}, either the
-#' project root or a subdirectory of the project.
-#' @param search logical. If \code{TRUE}, search parent directories
-#' to find the nearest drake cache. Otherwise, look in the
-#' current working directory only.
-#' @param verbose whether to print console messages
+#'   in the cache
+#'
+#' @inheritParams cached
+#'
 #' @param jobs number of jobs/workers for parallel processing
+#'
 #' @param targets_only logical, whether to output information
-#' only on the targets in your workflow plan data frame.
-#' If \code{targets_only} is \code{FALSE}, the output will
-#' include the hashes of both targets and imports. 
+#'   only on the targets in your workflow plan data frame.
+#'   If `targets_only` is `FALSE`, the output will
+#'   include the hashes of both targets and imports.
+#'
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -161,13 +153,13 @@ drake_cache_log <- function(
   path = getwd(),
   search = TRUE,
   cache = drake::get_cache(path = path, search = search, verbose = verbose),
-  verbose = TRUE,
+  verbose = drake::default_verbose(),
   jobs = 1,
   targets_only = FALSE
 ){
   if (is.null(cache)){
     return(
-      data.frame(
+      tibble(
         hash = character(0),
         type = character(0),
         name = character(0)
@@ -180,7 +172,8 @@ drake_cache_log <- function(
     jobs = jobs,
     cache = cache
   ) %>%
-    do.call(what = rbind)
+    do.call(what = rbind) %>%
+    as_tibble
   if (targets_only){
     out <- out[out$type == "target", ]
   }
@@ -197,5 +190,5 @@ single_cache_log <- function(key, cache){
   )
   imported <- ifelse(is.na(imported), TRUE, imported)
   type <- ifelse(imported, "import", "target")
-  data.frame(hash = hash, type = type, name = key, stringsAsFactors = FALSE)
+  tibble(hash = hash, type = type, name = key)
 }
