@@ -1,73 +1,57 @@
 #' @title Remove targets/imports from the cache.
-#' @description Cleans up the work done by \code{\link{make}()}.
+#' @description Cleans up the work done by [make()].
 #' @details
-#' By default, \code{clean()} removes references to cached data.
+#' By default, `clean()` removes references to cached data.
 #' To deep-clean the data to free up storage/memory, use
-#' \code{clean(garbage_collection = TRUE)}. Garbage collection is slower,
+#' `clean(garbage_collection = TRUE)`. Garbage collection is slower,
 #' but it purges data with no remaining references. To just do garbage
-#' collection without cleaning, see \code{\link{drake_gc}()}.
-#' Also, for \code{clean()}, you must be in your project's working directory
+#' collection without cleaning, see [drake_gc()].
+#' Also, for `clean()`, you must be in your project's working directory
 #' or a subdirectory of it.
-#' \code{clean(search = TRUE)} searches upwards in your folder structure
+#' `clean(search = TRUE)` searches upwards in your folder structure
 #' for the drake cache and acts on the first one it sees. Use
-#' \code{search == FALSE} to look within the current working
+#' `search = FALSE` to look within the current working
 #' directory only.
-#' WARNING: This deletes ALL work done with \code{\link{make}()},
+#' WARNING: This deletes ALL work done with [make()],
 #' which includes
-#' file targets as well as the entire drake cache. Only use \code{clean()}
+#' file targets as well as the entire drake cache. Only use `clean()`
 #' if you're sure you won't lose anything important.
-#' @seealso \code{\link{drake_gc}}, \code{\link{make}}
+#' @seealso [drake_gc()], [make()]
 #' @export
-#' @return Invisibly return \code{NULL}.
+#' @return Invisibly return `NULL`.
 #'
-#' @param ... targets to remove from the cache, as names (unquoted)
-#' or character strings (quoted). Similar to \code{...} in
-#' \code{\link{remove}(...)}.
-#' The symbols must not match other (formal) arguments of \code{clean()},
-#' such as \code{destroy}, \code{cache}, \code{path}, \code{search},
-#' \code{verbose}, or \code{jobs}. If there are name conflicts,
-#' use the \code{list} argument instead of \code{...}.
+#' @inheritParams cached
+#'
+#' @param ... targets to remove from the cache: as names (symbols),
+#'   character strings, or `dplyr`-style `tidyselect`
+#'   commands such as `starts_with()`.
 #'
 #' @param list character vector naming targets to be removed from the
-#' cache. Similar to the \code{list} argument of \code{\link{remove}()}.
+#'   cache. Similar to the `list` argument of [remove()].
 #'
 #' @param destroy logical, whether to totally remove the drake cache.
-#' If \code{destroy} is \code{FALSE}, only the targets
-#' from \code{make}()
-#' are removed. If \code{TRUE}, the whole cache is removed, including
-#' session metadata, etc.
-#'
-#' @param cache optional drake cache. See code{\link{new_cache}()}. If
-#' If \code{cache} is supplied,
-#' the \code{path} and \code{search} arguments are ignored.
-#'
-#' @param path Root directory of the drake project,
-#' or if \code{search} is \code{TRUE}, either the
-#' project root or a subdirectory of the project.
-#'
-#' @param search logical. If \code{TRUE}, search parent directories
-#' to find the nearest drake cache. Otherwise, look in the
-#' current working directory only.
-#'
-#' @param verbose whether to print console messages
+#'   If `destroy` is `FALSE`, only the targets
+#'   from `make()`
+#'   are removed. If `TRUE`, the whole cache is removed, including
+#'   session metadata, etc.
 #'
 #' @param jobs Number of jobs for light parallelism
-#' (disabled on Windows).
+#'   (disabled on Windows).
 #'
 #' @param force logical, whether to try to clean the cache
-#' even though the project may not be back compatible with the
-#' current version of drake.
+#'   even though the project may not be back compatible with the
+#'   current version of drake.
 #'
 #' @param garbage_collection logical, whether to call
-#' \code{cache$gc()} to do garbage collection.
-#' If \code{TRUE}, cached data with no remaining references
-#' will be removed.
-#' This will slow down \code{clean()}, but the cache
-#' could take up far less space afterwards.
-#' See the \code{gc()} method for \code{storr} caches.
+#'   `cache$gc()` to do garbage collection.
+#'   If `TRUE`, cached data with no remaining references
+#'   will be removed.
+#'   This will slow down `clean()`, but the cache
+#'   could take up far less space afterwards.
+#'   See the `gc()` method for `storr` caches.
 #'
 #' @param purge logical, whether to remove objects from
-#' metadata namespaces such as "meta", "build_times", and "errors".
+#'   metadata namespaces such as "meta", "build_times", and "errors".
 #'
 #' @examples
 #' \dontrun{
@@ -81,6 +65,9 @@
 #' clean(summ_regression1_large, small)
 #' # Those objects should be gone.
 #' cached(no_imported_objects = TRUE)
+#' # How about `tidyselect`?
+#' clean(starts_with("coef"))
+#' cached(no_imported_objects = TRUE)
 #' # Rebuild the missing targets.
 #' make(my_plan)
 #' # Remove all the targets and imports.
@@ -112,14 +99,12 @@ clean <- function(
   path = getwd(),
   search = TRUE,
   cache = NULL,
-  verbose = 1,
+  verbose = drake::default_verbose(),
   jobs = 1,
   force = FALSE,
   garbage_collection = FALSE,
   purge = FALSE
 ){
-  dots <- match.call(expand.dots = FALSE)$...
-  targets <- targets_from_dots(dots, list)
   if (is.null(cache)){
     cache <- get_cache(
       path = path, search = search, verbose = verbose, force = force)
@@ -127,6 +112,15 @@ clean <- function(
   if (is.null(cache)){
     return(invisible())
   }
+  targets <- drake_select(
+    cache = cache,
+    ...,
+    namespaces = target_namespaces(),
+    list = list
+  )
+  if (!length(targets) && is.null(c(...))){
+    targets <- cache$list()
+  }
   uncache(targets = targets, cache = cache, jobs = jobs, purge = purge)
   if (destroy){
     cache$destroy()
@@ -141,7 +135,6 @@ uncache <- function(targets, cache, jobs, purge){
   if (is.null(cache)){
     return()
   }
-  plan <- read_drake_plan(cache = cache)
   if (purge){
     namespaces <- target_namespaces(default = cache$default_namespace)
   } else {
@@ -165,7 +158,7 @@ uncache <- function(targets, cache, jobs, purge){
       X = files,
       FUN = remove_file_target,
       jobs = jobs,
-      plan = plan
+      cache = cache
     )
     lightly_parallelize(
       X = remove_these,
@@ -183,12 +176,13 @@ uncache_single <- function(target, cache, namespace){
   invisible()
 }
 
-remove_file_target <- function(target, plan){
+remove_file_target <- function(target, cache){
   if (
     is_file(target) &&
+    cache$exists(key = target, namespace = "meta") &&
     !is_imported(
       target = target,
-      plan = plan
+      cache = cache
     )
   ){
     drake_unquote(target) %>%
@@ -199,26 +193,16 @@ remove_file_target <- function(target, plan){
 
 #' @title Do garbage collection on the drake cache.
 #' @description The cache is a key-value store.
-#' By default, the \code{\link{clean}()} function removes
+#' By default, the [clean()] function removes
 #' values, but not keys.
 #' Garbage collection removes the remaining dangling files.
-#' @seealso \code{\link{clean}}
+#' @seealso [clean()]
 #' @export
-#' @return\code{NULL}
-#' @param path file path to the folder containing the cache.
-#' Yes, this is the parent directory containing the cache,
-#' not the cache itself, and it assumes the cache is in the
-#' `.drake` folder. If you are looking for a different cache
-#' with a known folder different from `.drake`, use
-#' the \code{\link{this_cache}()} function.
-#' @param search logical, whether to search back in the file system
-#' for the cache.
-#' @param verbose logical, whether to print the location of the cache
-#' @param cache the \code{drake}/\code{storr} cache object itself,
-#' if available.
+#' @return`NULL`
+#' @inheritParams cached
 #' @param force logical, whether to load the cache
-#' despite any back compatibility issues with the
-#' running version of drake.
+#'   despite any back compatibility issues with the
+#'   running version of drake.
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -235,7 +219,7 @@ remove_file_target <- function(target, plan){
 drake_gc <- function(
   path = getwd(),
   search = TRUE,
-  verbose = 1,
+  verbose = drake::default_verbose(),
   cache = NULL,
   force = FALSE
 ){
@@ -254,31 +238,28 @@ drake_gc <- function(
 }
 
 #' @title Try to repair a drake cache that is prone
-#' to throwing \code{storr}-related errors.
-#' @description Sometimes, \code{storr} caches may have
+#'   to throwing `storr`-related errors.
+#' @description Sometimes, `storr` caches may have
 #' dangling orphaned files that prevent you from loading or cleaning.
 #' This function tries to remove those files so you can use the
 #' cache normally again.
 #' @return The rescued drake/storr cache.
 #' @export
-#' @seealso \code{\link{get_cache}}, \code{\link{cached}},
-#' \code{\link{drake_gc}}, \code{\link{clean}}
+#' @seealso [get_cache()], [cached()],
+#'   [drake_gc()], [clean()]
+#' @inheritParams get_cache
 #' @param targets Character vector, names of the targets to rescue.
-#' As with many other drake utility functions, the word \code{target}
-#' is defined generally in this case, encompassing imports
-#' as well as true targets.
-#' If \code{targets} is \code{NULL}, everything in the
-#' cache is rescued.
-#' @param path same as for \code{\link{get_cache}()}
-#' @param search same as for \code{\link{get_cache}()}
-#' @param verbose same as for \code{\link{get_cache}()}
-#' @param force same as for \code{\link{get_cache}()}
+#'   As with many other drake utility functions, the word `target`
+#'   is defined generally in this case, encompassing imports
+#'   as well as true targets.
+#'   If `targets` is `NULL`, everything in the
+#'   cache is rescued.
 #' @param cache a `storr` cache object
 #' @param jobs number of jobs for light parallelism
-#' (disabled on Windows)
+#'   (disabled on Windows)
 #' @param garbage_collection logical, whether to do garbage collection
-#' as a final step. See \code{\link{drake_gc}} and \code{\link{clean}}
-#' for details.
+#'   as a final step. See [drake_gc()] and [clean()]
+#'   for details.
 #' @examples
 #' \dontrun{
 #' test_with_dir("Quarantine side effects.", {
@@ -293,7 +274,10 @@ drake_gc <- function(
 #' }
 rescue_cache <- function(
   targets = NULL,
-  path = getwd(), search = TRUE, verbose = 1, force = FALSE,
+  path = getwd(),
+  search = TRUE,
+  verbose = drake::default_verbose(),
+  force = FALSE,
   cache = drake::get_cache(
     path = path, search = search, verbose = verbose, force = force),
   jobs = 1,
