@@ -1,6 +1,6 @@
 run_future_lapply <- function(config){
   prepare_distributed(config = config)
-  run_parallel(config = config, worker = worker_future_lapply)
+  run_staged_parallelism(config = config, worker = worker_future_lapply)
   finish_distributed(config = config)
 }
 
@@ -14,6 +14,7 @@ worker_future_lapply <- function(targets, meta_list, config){
     x = targets,
     FUN = build_distributed,
     cache_path = config$cache$driver$path,
-    meta_list = meta_list
+    meta_list = meta_list,
+    future.globals = FALSE
   )
 }
