@@ -5,8 +5,12 @@
 library(future.batchtools)
 library(drake)
 
-# Use backend(multicore) instead for a dry run.
-backend(batchtools_torque(template = "torque.tmpl"))
+# Use future::plan(multicore) instead for a dry run.
+future::plan(
+  batchtools_torque,
+  template = "torque.tmpl",
+  workers = 4
+)
 
 load_basic_example()
 make(
