@@ -1,5 +1,10 @@
 drake_context("knitr")
 
+test_with_dir("empty cases", {
+  expect_equal(knitr_deps_list(NULL), list())
+  expect_equal(safe_get_tangled_frags(NULL), character(0))
+})
+
 test_with_dir("unparsable pieces of commands are handled correctly", {
   x <- "bluh$"
   expect_false(is_parsable(x))
@@ -19,24 +24,25 @@ test_with_dir("knitr_deps() works", {
   ))
   ans <- sort(c(
     paste0("target", seq_len(18)),
-    as_drake_filename(paste0("file", seq_len(6)))
+    file_store(paste0("file", seq_len(6)))
   ))
   expect_equal(sort(knitr_deps("'test.Rmd'")), ans)
   expect_false(file.exists("test.md"))
-  expect_warning(x <- knitr_deps("report.Rmd"))
+  expect_warning(x <- sort(knitr_deps("report.Rmd")))
+  expect_warning(expect_equal(x, sort(knitr_deps("\"report.Rmd\""))))
   expect_equal(x, character(0))
-  expect_equal(0, length(knitr_deps(character(0))))
   load_basic_example()
   x <- knitr_deps("report.Rmd")
-  y <- deps("knit('report.Rmd')")
-  z <- deps("render('report.Rmd')")
+  y <- expect_warning(deps("knit('report.Rmd')"))
+  z <- expect_warning(deps("render('report.Rmd')"))
+  w <- deps("funct(knitr_in(report.Rmd))")
   real_deps <- c(
     "small", "coef_regression2_small", "large"
   )
   expect_equal(sort(x), sort(real_deps))
-  expect_equal("targ", find_knitr_targets(function(x){
-    readd(targ)
-  }))
+  expect_equal(sort(y), sort(c(real_deps, "knit", "\"report.Rmd\"")))
+  expect_equal(sort(z), sort(c(real_deps, "render", "\"report.Rmd\"")))
+  expect_equal(sort(w), sort(c("funct")))
 })
 
 test_with_dir("find_knitr_doc() works", {
@@ -100,8 +106,6 @@ test_with_dir("knitr file deps from commands and functions", {
 })
 
 test_with_dir("misc knitr", {
-  o <- get_specific_arg(list(a = parse(text = "1 <- 2")), name = "a")
-  expect_equal(o, character(0))
   f <- function()
   expect_silent(o <- doc_of_function_call(knit))
   f <- function(x){
